SimpleLocationPicker class

Inheritance

Constructors

SimpleLocationPicker({double initialLatitude = SLPConstants.DEFAULT_LATITUDE, double initialLongitude = SLPConstants.DEFAULT_LONGITUDE, double zoomLevel = SLPConstants.DEFAULT_ZOOM_LEVEL, bool displayOnly = false, Color appBarColor = Colors.blueAccent, Color appBarTextColor = Colors.white, String appBarTitle = "Select Location", Color markerColor = Colors.blueAccent})

Properties

appBarColor → Color
Sets the appbar background color for the picker screen.
final
appBarTextColor → Color
Sets the appbar text color.
final
appBarTitle → String
Sets the appbar text color.
final
displayOnly → bool
Sets the mode of the picker. if true: enables DisplayOnly mode to display a marker on the map at a location only, no selection if false: enabled Picker mode allows to tap on the map to pick a location
final
hashCode → int
The hash code for this object.
no setterinherited
initialLatitude → double
Sets the initial location - latitude that the map must be centered on.
final
initialLongitude → double
Sets initial location - longitude that the map must be centered on.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
markerColor → Color
Sets the map marker icon background color.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zoomLevel → double
Sets the map zoom level.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _SimpleLocationPickerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited